
#include <STC12C5A.H>

//=============================================================
//Define LCD PIN IO
sbit CS=P1^0;		//chip select when low
sbit DC=P1^3;		//high :data  low:command    
sbit SCL=P1^1;		//SERIAL CLOCK INPUT    
sbit SDI=P1^2;	     //SERIAL DATA INPUT/OUTPUT   
sbit RES=P2^6;		//reset
sbit BL=P3^0;		//Backlight control

//Define key io 
sbit KEY = P2^7;  //NEXT

unsigned char USE_HORIZONTAL;   // 0,1 Vertical screen   2,3 Landscape screen


 
void lcd_Initial(void);
void Write_Cmd_Data(unsigned char);
void Write_Cmd(unsigned char);
void Write_Data(unsigned char DH,unsigned char DL);
void delayms(unsigned int tt);
void Write_Data_U16(unsigned int y);
void LCD_SetPos(unsigned int x1,unsigned int y1,unsigned int x2,unsigned int y2);
void ClearScreen(unsigned int bColor);
void Draw_Circle(unsigned int x0,unsigned int y0,unsigned char r,unsigned int color);
void LCD_DrawRectangle(unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2,unsigned int color);
void LCD_DrawLine(unsigned int x1,unsigned int y1,unsigned int x2,unsigned int y2,unsigned int color);
void LCD_DrawPoint(unsigned int x,unsigned int y,unsigned int color);
void showzifustr(unsigned int x,unsigned int y,unsigned char *str,unsigned int dcolor,unsigned int bgcolor);
void showzifu(unsigned int x,unsigned int y,unsigned char value,unsigned int dcolor,unsigned int bgcolor);
  
unsigned int code pic[];
unsigned char code String6_12[];

//===============================================================
//clear screen  
void ClearScreen(unsigned int bColor)
{
 unsigned int i,j;
LCD_SetPos(0,0,95,53); 
 for (i=0;i<54;i++)
	{
	
	   for (j=0;j<96;j++)
	       Write_Data_U16(bColor);
	}
}



//===============================================================
//write parameter
void  Write_Cmd_Data (unsigned char CMDP)
{ unsigned char i;
 	 
    CS=0;
   	DC=1;
    for(i=0;i<8;i++)
     {  SCL=0;
        if(CMDP&0x80) SDI=1;
       	else SDI=0;
       	SCL=1;
        CMDP=CMDP<<1;
     }
   	CS=1;

}


//=============================================================
//write command

void Write_Cmd(unsigned char CMD)
{ unsigned char i;
 	 
    CS=0;
   	DC=0;
    for(i=0;i<8;i++)
     {  SCL=0;
        if(CMD&0x80) SDI=1;
       	else SDI=0;
       	SCL=1;
        CMD=CMD<<1;
     }
   	CS=1;


}


//==============================================================
//write  data word
void  Write_Data_U16(unsigned int y)
{
	unsigned char m,n;
	m=y>>8;
	n=y;
	Write_Data(m,n);

}


//===================================================================
//write data byte

void Write_Data(unsigned char DH,unsigned char DL)
{unsigned char i;
 	 
    CS=0;
   	DC=1;
    for(i=0;i<8;i++)
     {  SCL=0;
        if(DH&0x80) SDI=1;
       	else SDI=0;
       	SCL=1;
        DH=DH<<1;
     }

    for(i=0;i<8;i++)
     {  SCL=0;
        if(DL&0x80) SDI=1;
       	else SDI=0;
       	SCL=1;
        DL=DL<<1;
     }

   	CS=1;

}



//============================================================
//delay
void delayms(unsigned int count)
{
    int i,j;                                                                                
    for(i=0;i<count;i++)                                                                    
       {
	     for(j=0;j<1000;j++);
       }                                                                                     
}


//show one Character
void showzifu(unsigned int x,unsigned int y,unsigned char value,unsigned int dcolor,unsigned int bgcolor)	
{  
	unsigned char i,j;
	unsigned char *temp=String6_12;    
    LCD_SetPos(x,y,x+7,y+11);      
	temp+=(value-32)*12;
	for(j=0;j<12;j++)
	{
		for(i=0;i<8;i++)
		{ 		     
		 	if((*temp&(1<<(7-i)))!=0)
			{
				Write_Data(dcolor>>8,dcolor);
			} 
			else
			{
				Write_Data(bgcolor>>8,bgcolor);
			}   
		}
		temp++;
	 }
}

//show String
void showzifustr(unsigned int x,unsigned int y,unsigned char *str,unsigned int dcolor,unsigned int bgcolor)	  
{  
	unsigned int x1,y1;
	x1=x;
	y1=y;
	while(*str!='\0')
	{	
		showzifu(x1,y1,*str,dcolor,bgcolor);
		x1+=7;
		str++;
	}	
}




void LCD_DrawPoint(unsigned int x,unsigned int y,unsigned int color)
{
	LCD_SetPos(x,y,x,y);
	Write_Data_U16(color);
} 

void LCD_DrawLine(unsigned int x1,unsigned int y1,unsigned int x2,unsigned int y2,unsigned int color)
{
	unsigned int t; 
	int xerr=0,yerr=0,delta_x,delta_y,distance;
	int incx,incy,uRow,uCol;
	delta_x=x2-x1; 
	delta_y=y2-y1;
	uRow=x1;
	uCol=y1;
	if(delta_x>0)incx=1; 
	else if (delta_x==0)incx=0;
	else {incx=-1;delta_x=-delta_x;}
	if(delta_y>0)incy=1;
	else if (delta_y==0)incy=0;
	else {incy=-1;delta_y=-delta_x;}
	if(delta_x>delta_y)distance=delta_x;  
	else distance=delta_y;
	for(t=0;t<distance+1;t++)
	{
		LCD_DrawPoint(uRow,uCol,color);
		xerr+=delta_x;
		yerr+=delta_y;
		if(xerr>distance)
		{
			xerr-=distance;
			uRow+=incx;
		}
		if(yerr>distance)
		{
			yerr-=distance;
			uCol+=incy;
		}
	}
}



void LCD_DrawRectangle(unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2,unsigned int color)
{
	LCD_DrawLine(x1,y1,x2,y1,color);
	LCD_DrawLine(x1,y1,x1,y2,color);
	LCD_DrawLine(x1,y2,x2,y2,color);
	LCD_DrawLine(x2,y1,x2,y2,color);
}


void Draw_Circle(unsigned int x0,unsigned int y0,unsigned char r,unsigned int color)
{
	int a,b;
	a=0;b=r;	  
	while(a<=b)
	{
		LCD_DrawPoint(x0-b,y0-a,color);             //3           
		LCD_DrawPoint(x0+b,y0-a,color);             //0           
		LCD_DrawPoint(x0-a,y0+b,color);             //1                
		LCD_DrawPoint(x0-a,y0-b,color);             //2             
		LCD_DrawPoint(x0+b,y0+a,color);             //4               
		LCD_DrawPoint(x0+a,y0-b,color);             //5
		LCD_DrawPoint(x0+a,y0+b,color);             //6 
		LCD_DrawPoint(x0-b,y0+a,color);             //7
		a++;
		if((a*a+b*b)>(r*r))
		{
			b--;
		}
	}
}



//============================================================
//show gray

void DispRGBGray(void)
{  

	unsigned int  A,B,C;
    unsigned int  i,j,k,DH;

	LCD_SetPos(0,0,95,53); 



	for(k=0;k<14;k++)
	{   
    	A=0;
    	B=0;
    	C=0;
		for(i=0;i<16;i++)
		{    
    		for(j=0;j<6;j++)
    		{
     			DH=(A<<11)+(B<<5)+C;
     			Write_Data_U16(DH);
    		}
    		A=A+2;
   			B=B+4;
    		C=C+2;
  		}
    	
	}



	for(k=0;k<14;k++)
	{   
    	A=0;
    	B=0;
    	C=0;
		for(i=0;i<16;i++)
		{    
    		for(j=0;j<6;j++)
    		{
     			DH=(A<<11)+B+C;
     			Write_Data_U16(DH);
    		}
    		A=A+2;

  		}
    	
	}

	for(k=0;k<14;k++)
	{   
    	A=0;
    	B=0;
    	C=0;
		for(i=0;i<16;i++)
		{    
    		for(j=0;j<6;j++)
    		{
     			DH=A+(B<<5)+C;
     			Write_Data_U16(DH);
    		}
    		B=B+4;

  		}
    	
	}

	for(k=0;k<12;k++)
	{   
    	A=0;
    	B=0;
    	C=0;
		for(i=0;i<16;i++)
		{    
    		for(j=0;j<6;j++)
    		{
     			DH=A+B+C;
     			Write_Data_U16(DH);
    		}
    		C=C+2;

  		}
    	
	}




}




//============================================================
//show picture
void show_picture(void)
{ 
	unsigned char i,j;
	unsigned int n=0;


   LCD_SetPos(0,0,95,53);
	for(j=0;j<54;j++)
	{
		for(i=0;i<96;i++)
		{
            Write_Data_U16(pic[n++]);
	    }
		  
	}


    return;
}


//=============================================================
//LCD Initial

void lcd_Initial(void)
{ 
  	CS=1;
	delayms(5);
	RES=0;
	delayms(50);
	RES=1;
	delayms(120);  


	Write_Cmd(0x11); //Sleep out
	delayms(120); //Delay 120ms
//------------------------------------ST7735S Frame Rate-----------------------------------------//


	Write_Cmd(0xB1);     //------------------------------------ST7735S Frame Rate-----------------------------------------//
	Write_Cmd_Data(0x05);   
	Write_Cmd_Data(0x3C);   
	Write_Cmd_Data(0x3C);   

	Write_Cmd(0xB2);     
	Write_Cmd_Data(0x05);   
	Write_Cmd_Data(0x3C);   
	Write_Cmd_Data(0x3C);   

	Write_Cmd(0xB3);     
	Write_Cmd_Data(0x05);   
	Write_Cmd_Data(0x3C);   
	Write_Cmd_Data(0x3C);   
	Write_Cmd_Data(0x05);   
	Write_Cmd_Data(0x3C);   
	Write_Cmd_Data(0x3C);   //------------------------------------End ST7735S Frame Rate-----------------------------------------//

	Write_Cmd(0xB4);     //Dot inversion
	Write_Cmd_Data(0x03);   

	Write_Cmd(0xC0);     //------------------------------------ST7735S Power Sequence-----------------------------------------//
	Write_Cmd_Data(0x0E);   
	Write_Cmd_Data(0x0E);   
	Write_Cmd_Data(0x04);   

	Write_Cmd(0xC1);     
	Write_Cmd_Data(0xC0);   

	Write_Cmd(0xC2);     
	Write_Cmd_Data(0x0D);   
	Write_Cmd_Data(0x00);   

	Write_Cmd(0xC3);     
	Write_Cmd_Data(0x8D);   
	Write_Cmd_Data(0x2A);   

	Write_Cmd(0xC4);     
	Write_Cmd_Data(0x8D);   
	Write_Cmd_Data(0xEE);   //---------------------------------End ST7735S Power Sequence-------------------------------------//

	Write_Cmd(0xC5);     //VCOM
	Write_Cmd_Data(0x04);   

	Write_Cmd(0x36);     //MX, MY, RGB mode
	Write_Cmd_Data(0xC8);   

	Write_Cmd(0x3a);  
	Write_Cmd_Data(0x05);  


	Write_Cmd(0xE0);     
	Write_Cmd_Data(0x05);   
	Write_Cmd_Data(0x1A);   
	Write_Cmd_Data(0x0B);   
	Write_Cmd_Data(0x15);   
	Write_Cmd_Data(0x3D);   
	Write_Cmd_Data(0x38);   
	Write_Cmd_Data(0x2E);   
	Write_Cmd_Data(0x30);   
	Write_Cmd_Data(0x2D);   
	Write_Cmd_Data(0x28);   
	Write_Cmd_Data(0x30);   
	Write_Cmd_Data(0x3B);   
	Write_Cmd_Data(0x00);   
	Write_Cmd_Data(0x01);   
	Write_Cmd_Data(0x02);   
	Write_Cmd_Data(0x10);   

	Write_Cmd(0xE1);     
	Write_Cmd_Data(0x05);   
	Write_Cmd_Data(0x1A);   
	Write_Cmd_Data(0x0B);   
	Write_Cmd_Data(0x15);   
	Write_Cmd_Data(0x36);   
	Write_Cmd_Data(0x2E);   
	Write_Cmd_Data(0x28);   
	Write_Cmd_Data(0x2B);   
	Write_Cmd_Data(0x2B);   
	Write_Cmd_Data(0x28);   
	Write_Cmd_Data(0x30);   
	Write_Cmd_Data(0x3B);   
	Write_Cmd_Data(0x00);   
	Write_Cmd_Data(0x01);   
	Write_Cmd_Data(0x02);   
	Write_Cmd_Data(0x10);  

	Write_Cmd(0x20); //

	Write_Cmd(0x29); 




}


//===============================================================
 void LCD_SetPos(unsigned int x1,unsigned int y1,unsigned int x2,unsigned int y2)
{	
 

 		Write_Cmd(0x36);
 	if(USE_HORIZONTAL==0)	Write_Cmd_Data(0xC8);
	else if(USE_HORIZONTAL==1)	Write_Cmd_Data(0x08);
	else if(USE_HORIZONTAL==2)	Write_Cmd_Data(0x78);
	else 	Write_Cmd_Data(0xA8);
  

	if(USE_HORIZONTAL==0)
	{
	Write_Cmd(0x2a);
    Write_Data_U16(x1+16);
    Write_Data_U16(x2+16);
	Write_Cmd(0x2b);
    Write_Data_U16(y1+106);
    Write_Data_U16(y2+106);
		Write_Cmd(0x2c);
	}
	else if(USE_HORIZONTAL==1)
	{
	Write_Cmd(0x2a);
    Write_Data_U16(x1+16);
    Write_Data_U16(x2+16);
	Write_Cmd(0x2b);
    Write_Data_U16(y1);
    Write_Data_U16(y2);
		Write_Cmd(0x2c);		
	}
	else if(USE_HORIZONTAL==2)
	{
	Write_Cmd(0x2a);
    Write_Data_U16(x1);
    Write_Data_U16(x2);
	Write_Cmd(0x2b);
    Write_Data_U16(y1+16);
    Write_Data_U16(y2+16);
	Write_Cmd(0x2c);		
	}
	else
	{
	Write_Cmd(0x2a);
    Write_Data_U16(x1+106);
    Write_Data_U16(x2+106);
	Write_Cmd(0x2b);
    Write_Data_U16(y1+16);
    Write_Data_U16(y2+16);
	Write_Cmd(0x2c);			
	}

}

unsigned char code String6_12[]={         
/*--   --*/
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
/*--  !  --*/
0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x20,0x00,0x00,
/*--  "  --*/
0x00,0x28,0x50,0x50,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
/*--  #  --*/
0x00,0x00,0x28,0x28,0xFC,0x28,0x50,0xFC,0x50,0x50,0x00,0x00,
/*--  $  --*/
0x00,0x20,0x78,0xA8,0xA0,0x60,0x30,0x28,0xA8,0xF0,0x20,0x00,
/*-- %  --*/
0x00,0x00,0x48,0xA8,0xB0,0x50,0x28,0x34,0x54,0x48,0x00,0x00,
/*--  &  --*/
0x00,0x00,0x20,0x50,0x50,0x78,0xA8,0xA8,0x90,0x6C,0x00,0x00,
/*--  '  --*/
0x00,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
/*--  (  --*/
0x00,0x04,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x04,0x00,
/*--  )  --*/
0x00,0x40,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0x40,0x00,
/*--   *  --*/
0x00,0x00,0x00,0x20,0xA8,0x70,0x70,0xA8,0x20,0x00,0x00,0x00,
/*--   +  --*/
0x00,0x00,0x20,0x20,0x20,0xF8,0x20,0x20,0x20,0x00,0x00,0x00,
/*-  ,  --*/
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x80,
/*--  -  --*/
0x00,0x00,0x00,0x00,0x00,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,
/*--   .  --*/
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,0x00,
/*--    /  --*/
0x00,0x08,0x10,0x10,0x10,0x20,0x20,0x40,0x40,0x40,0x80,0x00,
/*--   0  --*/
0x00,0x00,0x70,0x88,0x88,0x88,0x88,0x88,0x88,0x70,0x00,0x00,
/*--  1  --*/
0x00,0x00,0x20,0x60,0x20,0x20,0x20,0x20,0x20,0x70,0x00,0x00,
/*--   2  --*/
0x00,0x00,0x70,0x88,0x88,0x10,0x20,0x40,0x80,0xF8,0x00,0x00,
/*--   3  --*/
0x00,0x00,0x70,0x88,0x08,0x30,0x08,0x08,0x88,0x70,0x00,0x00,
/*--  4  --*/
0x00,0x00,0x10,0x30,0x50,0x50,0x90,0x78,0x10,0x18,0x00,0x00,
/*--   5  --*/
0x00,0x00,0xF8,0x80,0x80,0xF0,0x08,0x08,0x88,0x70,0x00,0x00,
/*--   6  --*/
0x00,0x00,0x70,0x90,0x80,0xF0,0x88,0x88,0x88,0x70,0x00,0x00,
/*--   7  --*/
0x00,0x00,0xF8,0x90,0x10,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
/*-- 8  --*/
0x00,0x00,0x70,0x88,0x88,0x70,0x88,0x88,0x88,0x70,0x00,0x00,
/*--   9  --*/
0x00,0x00,0x70,0x88,0x88,0x88,0x78,0x08,0x48,0x70,0x00,0x00,
/*--   :  --*/
0x00,0x00,0x00,0x00,0x20,0x00,0x00,0x00,0x00,0x20,0x00,0x00,
/*--   ;  --*/
0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x00,0x00,0x20,0x20,0x00,
/*--   <  --*/
0x00,0x04,0x08,0x10,0x20,0x40,0x20,0x10,0x08,0x04,0x00,0x00,
/*--  =  --*/
0x00,0x00,0x00,0x00,0xF8,0x00,0x00,0xF8,0x00,0x00,0x00,0x00,
/*--  >  --*/
0x00,0x40,0x20,0x10,0x08,0x04,0x08,0x10,0x20,0x40,0x00,0x00,
/*--  ?  --*/
0x00,0x00,0x70,0x88,0x88,0x10,0x20,0x20,0x00,0x20,0x00,0x00,
/*--   @  --*/
0x00,0x00,0x70,0x88,0x98,0xA8,0xA8,0xB8,0x80,0x78,0x00,0x00,
/*--  A  --*/
0x00,0x00,0x20,0x20,0x30,0x50,0x50,0x78,0x48,0xCC,0x00,0x00,
/*--   B  --*/
0x00,0x00,0xF0,0x48,0x48,0x70,0x48,0x48,0x48,0xF0,0x00,0x00,
/*--  C  --*/
0x00,0x00,0x78,0x88,0x80,0x80,0x80,0x80,0x88,0x70,0x00,0x00,
/*--  D  --*/
0x00,0x00,0xF0,0x48,0x48,0x48,0x48,0x48,0x48,0xF0,0x00,0x00,
/*--  E  --*/
0x00,0x00,0xF8,0x48,0x50,0x70,0x50,0x40,0x48,0xF8,0x00,0x00,
/*--   F  --*/
0x00,0x00,0xF8,0x48,0x50,0x70,0x50,0x40,0x40,0xE0,0x00,0x00,
/*--   G  --*/
0x00,0x00,0x38,0x48,0x80,0x80,0x9C,0x88,0x48,0x30,0x00,0x00,
/*--  H  --*/
0x00,0x00,0xCC,0x48,0x48,0x78,0x48,0x48,0x48,0xCC,0x00,0x00,
/*--   I  --*/
0x00,0x00,0xF8,0x20,0x20,0x20,0x20,0x20,0x20,0xF8,0x00,0x00,
/*--   J  --*/
0x00,0x00,0x7C,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0xE0,0x00,
/*--   K  --*/
0x00,0x00,0xEC,0x48,0x50,0x60,0x50,0x50,0x48,0xEC,0x00,0x00,
/*--   L  --*/
0x00,0x00,0xE0,0x40,0x40,0x40,0x40,0x40,0x44,0xFC,0x00,0x00,
/*--  M  --*/
0x00,0x00,0xD8,0xD8,0xD8,0xD8,0xA8,0xA8,0xA8,0xA8,0x00,0x00,
/*--   N  --*/
0x00,0x00,0xDC,0x48,0x68,0x68,0x58,0x58,0x48,0xE8,0x00,0x00,
/*--   O  --*/
0x00,0x00,0x70,0x88,0x88,0x88,0x88,0x88,0x88,0x70,0x00,0x00,
/*--   P  --*/
0x00,0x00,0xF0,0x48,0x48,0x70,0x40,0x40,0x40,0xE0,0x00,0x00,
/*--   Q  --*/
0x00,0x00,0x70,0x88,0x88,0x88,0x88,0xE8,0x98,0x70,0x18,0x00,
/*--  R  --*/
0x00,0x00,0xF0,0x48,0x48,0x70,0x50,0x48,0x48,0xEC,0x00,0x00,
/*--   S  --*/
0x00,0x00,0x78,0x88,0x80,0x60,0x10,0x08,0x88,0xF0,0x00,0x00,
/*--   T  --*/
0x00,0x00,0xF8,0xA8,0x20,0x20,0x20,0x20,0x20,0x70,0x00,0x00,
/*--   U  --*/
0x00,0x00,0xCC,0x48,0x48,0x48,0x48,0x48,0x48,0x30,0x00,0x00,
/*--    V  --*/
0x00,0x00,0xCC,0x48,0x48,0x50,0x50,0x30,0x20,0x20,0x00,0x00,
/*--   W  --*/
0x00,0x00,0xA8,0xA8,0xA8,0x70,0x50,0x50,0x50,0x50,0x00,0x00,
/*--    X  --*/
0x00,0x00,0xD8,0x50,0x50,0x20,0x20,0x50,0x50,0xD8,0x00,0x00,
/*--    Y  --*/
0x00,0x00,0xD8,0x50,0x50,0x20,0x20,0x20,0x20,0x70,0x00,0x00,
/*--    Z  --*/
0x00,0x00,0xF8,0x90,0x10,0x20,0x20,0x40,0x48,0xF8,0x00,0x00,
/*--   [  --*/
0x00,0x38,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x38,0x00,
/*--    \  --*/
0x00,0x40,0x40,0x40,0x20,0x20,0x10,0x10,0x10,0x08,0x00,0x00,
/*--    ]  --*/
0x00,0x70,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x70,0x00,
/*--    ^  --*/
0x00,0x20,0x50,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
/*--   _  --*/
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFC,
/*--   `  --*/
0x00,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
/*--  a  --*/
0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x38,0x48,0x3C,0x00,0x00,
/*--   b  --*/
0x00,0x00,0xC0,0x40,0x40,0x70,0x48,0x48,0x48,0x70,0x00,0x00,
/*--   c  --*/
0x00,0x00,0x00,0x00,0x00,0x38,0x48,0x40,0x40,0x38,0x00,0x00,
/*--  d  --*/
0x00,0x00,0x18,0x08,0x08,0x38,0x48,0x48,0x48,0x3C,0x00,0x00,
/*--    e  --*/
0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x78,0x40,0x38,0x00,0x00,
/*--   f  --*/
0x00,0x00,0x1C,0x20,0x20,0x78,0x20,0x20,0x20,0x78,0x00,0x00,
/*--   g  --*/
0x00,0x00,0x00,0x00,0x00,0x3C,0x48,0x30,0x40,0x78,0x44,0x38,
/*--    h  --*/
0x00,0x00,0xC0,0x40,0x40,0x70,0x48,0x48,0x48,0xEC,0x00,0x00,
/*--   i  --*/
0x00,0x00,0x20,0x00,0x00,0x60,0x20,0x20,0x20,0x70,0x00,0x00,
/*--   j  --*/
0x00,0x00,0x10,0x00,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0xE0,
/*--   k  --*/
0x00,0x00,0xC0,0x40,0x40,0x5C,0x50,0x70,0x48,0xEC,0x00,0x00,
/*--  l  --*/
0x00,0x00,0xE0,0x20,0x20,0x20,0x20,0x20,0x20,0xF8,0x00,0x00,
/*--   m  --*/
0x00,0x00,0x00,0x00,0x00,0xF0,0xA8,0xA8,0xA8,0xA8,0x00,0x00,
/*--    n  --*/
0x00,0x00,0x00,0x00,0x00,0xF0,0x48,0x48,0x48,0xEC,0x00,0x00,
/*--    o  --*/
0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x48,0x30,0x00,0x00,
/*--   p  --*/
0x00,0x00,0x00,0x00,0x00,0xF0,0x48,0x48,0x48,0x70,0x40,0xE0,
/*--  q  --*/
0x00,0x00,0x00,0x00,0x00,0x38,0x48,0x48,0x48,0x38,0x08,0x1C,
/*--    r  --*/
0x00,0x00,0x00,0x00,0x00,0xD8,0x60,0x40,0x40,0xE0,0x00,0x00,
/*--    s  --*/
0x00,0x00,0x00,0x00,0x00,0x78,0x40,0x30,0x08,0x78,0x00,0x00,
/*--   t  --*/
0x00,0x00,0x00,0x20,0x20,0x70,0x20,0x20,0x20,0x18,0x00,0x00,
/*--    u  --*/
0x00,0x00,0x00,0x00,0x00,0xD8,0x48,0x48,0x48,0x3C,0x00,0x00,
/*--   v  --*/
0x00,0x00,0x00,0x00,0x00,0xEC,0x48,0x50,0x30,0x20,0x00,0x00,
/*--   w  --*/
0x00,0x00,0x00,0x00,0x00,0xA8,0xA8,0x70,0x50,0x50,0x00,0x00,
/*--  x  --*/
0x00,0x00,0x00,0x00,0x00,0xD8,0x50,0x20,0x50,0xD8,0x00,0x00,
/*--   y  --*/
0x00,0x00,0x00,0x00,0x00,0xEC,0x48,0x50,0x30,0x20,0x20,0xC0,
/*--  z  --*/
0x00,0x00,0x00,0x00,0x00,0x78,0x10,0x20,0x20,0x78,0x00,0x00,
/* {  --*/
0x00,0x18,0x10,0x10,0x10,0x20,0x10,0x10,0x10,0x10,0x18,0x00,
/*--    |  --*/
0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
/*--   }  --*/
0x00,0x60,0x20,0x20,0x20,0x10,0x20,0x20,0x20,0x20,0x60,0x00,
/*--  ~  --*/
0x40,0xA4,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,

};  





unsigned int code pic[]=
{
//----- D:\̲\Ʒļ\TFT\0.42\ͼƬ\96543.bmp
//----- H - L, x direct, 8 pixel mode, 64k color R5G6B5.
//----- width x height = 96 x 54, Total bytes = 10368
0x0000,0x0000,0x0000,0x0000,0x19c2,0x43a3,0x32c3,0x5ca6,0x53e6,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x2102,0x5b65,0x1040,0x53e5,0xaea8,0x2980,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0801,0x410d,0x5995,0x5197,0x4953,0x490e,0x6195,0x6998,0x71d9,0x28c9,0x0000,0x0882,0x29c4,0xe6ea,0xffee,0xfee4,0xfda1,0xac22,0x1102,0x0000,0x0000,0x0800,0x49c1,0x7240,0x73e4,0x5468,0x7529,0x5ca7,0x3be5,0x4c25,0x33e5,0x5566,0xcba6,0x9800,0x1887,0x50d1,0xb881,0xd945,0xd1c7,0xfacb,0xf28a,0xd187,0xd0c4,0x0000,0x0000,0x0000,0x0000,0x19c2,0x4363,0x3324,0x6d27,0x4ba6,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0001,0x6ca6,0x4282,0x6ba5,0x95a5,0x2981,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0001,0x390d,0x5152,0x5953,0x5995,0x410f,0x410e,0x6196,0x69d8,0x414f,0x0000,0x0000,0x3a03,0xf78a,0xffed,0xff48,0xfe63,0xfde1,0xb3e1,0x0001,0x0000,0x0000,0x3901,0x5a41,0x53e6,0x64a8,0x7528,0x4be5,0x4425,0x3be5,0x4465,0x7ca4,0xe286,0xd843,0x2000,0x4041,0xd0c2,0xc105,0xe209,0xea49,0xd186,0xc946,0xb883,
0x0000,0x0000,0x0000,0x0000,0x1981,0x4363,0x3b23,0x6d68,0x4ba6,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x5be5,0xade7,0xe523,0xb4a2,0x29c2,0x0841,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1043,0x410e,0x4910,0x5151,0x4951,0x410e,0x4910,0x5153,0x5995,0x1886,0x0000,0x2982,0xf78a,0xffec,0xffc9,0xee24,0xf5e2,0xfde2,0x8b22,0x0001,0x0000,0x1880,0x4a42,0x4ba6,0x6ca7,0x5c67,0x43e4,0x4c26,0x3424,0x4c22,0x9325,0xfa49,0xd8c4,0x3000,0x6040,0xc883,0xb8c4,0xd147,0xc946,0xc104,0xb083,0xb843,0x0000,0x0000,0x0000,0x0000,0x1101,0x43a3,0x32c3,0x6d27,0x53a6,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x3183,0x0841,0x6ac2,0xe5e4,0xfee5,0xdd22,0x8322,0x1041,0x0000,0x2103,0x1041,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x390c,0x390d,0x30cc,0x410f,0x490f,0x5151,0x5153,0x38d0,0x0804,0x1901,0xe6e9,0xffea,0xff89,0xff48,0xede4,0xf5a1,0xed61,0x6a42,0x0001,0x0000,0x3204,0x4b66,0x5c26,0x4365,0x43e5,0x33a4,0x4c26,0x9533,0xd5ba,0xfbae,0xc8c2,0x5001,0x7842,0xa842,0xa843,0xa843,0xb083,0xb083,0x9002,0x9843,
0x0000,0x0000,0x0000,0x0000,0x0000,0x3b23,0x3b23,0x6527,0x5be6,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x9ca6,0xac65,0x38c0,0xe522,0xff46,0xe5a3,0xcc61,0x5140,0x94a9,0xee27,0x0840,0x0000,0x0000,0x0000,0x2105,0x0001,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0001,0x310b,0x5153,0x4910,0x494f,0x38cf,0x3893,0x3856,0x4093,0x5151,0x284d,0x0043,0xce67,0xffe8,0xff48,0xff89,0xf665,0xeda2,0xeda2,0xe521,0x3101,0x0001,0x3204,0x42c4,0x3a84,0x2a84,0x22c4,0x2361,0x8533,0xe6bf,0xdfff,0xf536,0xc000,0x5800,0x7000,0x8000,0x7000,0x6800,0x9001,0x8802,0x9803,0x4001,0x0000,0x0000,0x0000,0x0000,0x0000,0x2a02,0x3ba4,0x5ce7,0x6467,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x4a44,0xf666,0x7240,0xdd22,0xfea5,0xdda3,0xb3e0,0xee67,0xffed,0xd4a2,0x0000,0x0000,0x2946,0xad79,0xc63d,0x94b6,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1886,0x390d,0x28ca,0x494e,0x4915,0x5152,0x728f,0x9bed,0xcd6b,0xe629,0xbce8,0x4245,0xb566,0xffe9,0xf6a6,0xfee6,0xfee6,0xee24,0xf5e2,0xf5a1,0x8b21,0x0882,0x29c4,0x3203,0x0902,0x0982,0x74a5,0xcea6,0xff91,0xdeff,0xcf9f,0xfc31,0x9800,0x6042,0xab6f,0xc537,0xc577,0x9acc,0x8001,0x7800,0x2800,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0881,0x3b23,0x5ca6,0x6ce8,0x0000,0x0000,0x0000,0x0000,0x0000,0x10c2,0x2983,0x3244,0x3a84,0x3a84,0x3244,0x29c3,0x1903,0x0841,0x0000,0x0000,0x0000,0xc5a8,0xcd23,0xdce1,0xede4,0xc461,0xc4e2,0xffed,0xff87,0xdca0,0x1840,0x0000,0x9d38,0xe6ff,0xce7d,0xffff,0x5acb,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x30cb,0x6196,0x390d,0x390b,0x38cf,0x40d3,0xe66e,0xffe9,0xffe8,0xffe9,0xffea,0xffc9,0xd629,0xcda6,0xffe6,0xf6e5,0xf6a5,0xfee6,0xee24,0xeda1,0xeda2,0xd4a1,0x4a02,0x1143,0x0881,0x00c1,0xad67,0xffeb,0xffed,0xffea,0xd5e9,0xb5bd,0xeacc,0x91c9,0xb5bb,0xe7ff,0xefff,0xffff,0xffff,0xedf9,0xeb6d,0x92cc,0x8b2b,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x2182,0x54a6,0x7da9,0x0881,0x0000,0x0001,0x3a44,0x6467,0x7d29,0x85e9,0x8dea,0x8e29,0x962a,0x962a,0x8e2a,0x85ea,0x7529,0x5c27,0x3a85,0x0881,0x41c4,0xbca4,0xdca0,0xdd22,0x7a40,0xb4a2,0xffeb,0xfe62,0xf560,0x7240,0x0844,0xc63c,0xc63d,0xdebe,0xffff,0xbdf8,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x30cb,0x7a1c,0x69d9,0x69d9,0x5119,0xab67,0xffe5,0xffed,0xffee,0xffec,0xffeb,0xffc9,0xf6a7,0xc567,0xf745,0xffe5,0xf6a5,0xfea5,0xf624,0xe562,0xf5a2,0xed21,0x7b22,0x0001,0x0041,0xce28,0xffed,0xffec,0xffed,0xff89,0xed60,0xc4ad,0xb437,0x9dbc,0xceff,0xef5e,0xffdf,0xffdf,0xf7df,0xf7ff,0xfebc,0xfdf9,0xfdfa,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x43a4,0x7e29,0x2983,0x2983,0x6ca8,0x7da9,0x6ce8,0x5c67,0x53e6,0x53e6,0x5426,0x5c67,0x6467,0x6ce8,0x7569,0x85e9,0x96aa,0x9eec,0x7daa,0x4ba7,0x5b25,0xaba1,0xbb60,0x7283,0xd636,0xeeaa,0xfea8,0xeda2,0x9ac0,0x6287,0xad7c,0xc63d,0xef5f,0xffff,0xe75e,0x0000,0x0000,0x0841,0x4a8b,0x6b6e,0x39c8,0x0000,0x0000,0x0000,0x0000,0x0000,0x1886,0x7a1b,0x6998,0x4919,0x8a8f,0xe520,0xf5a0,0xfee6,0xff8a,0xffcb,0xffca,0xffca,0xffe9,0xd667,0xc5a6,0xffe5,0xff44,0xf6a5,0xfea5,0xe562,0xeda1,0xed22,0x72c1,0x0001,0xbda8,0xffed,0xffeb,0xffcb,0xff8a,0xfea4,0xf5a0,0xb426,0x7cba,0xb5bb,0xe6ff,0xffff,0xffff,0xf79e,0xef5f,0xf7ff,0xffff,0xfacb,0xe105,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1101,0x6d68,0x74e8,0x5c27,0x5426,0x4325,0x3ac5,0x3325,0x3325,0x3b25,0x3b24,0x3324,0x3b25,0x3b65,0x43e5,0x4c26,0x5466,0x64e8,0x7da9,0x8e6a,0x75ea,0x6465,0x8be7,0xffdf,0xffff,0xce31,0xd62f,0xfffd,0xc4e7,0xac69,0xad7c,0xc63d,0xe75f,0xe6ff,0xc63d,0x0000,0x636c,0xe75d,0xf79f,0xef9f,0xef5f,0x8433,0x0842,0x0000,0x0000,0x0000,0x0000,0x390d,0x69d8,0x5158,0x69cf,0xd4a0,0xdd20,0xf5e1,0xf662,0xf665,0xfee8,0xffe9,0xff49,0xede7,0xc5a7,0xce26,0xffe5,0xff85,0xf6a4,0xe5a2,0xee60,0xdda0,0x5a80,0x95a8,0xffed,0xffea,0xffca,0xffca,0xf6a6,0xf5e2,0xed60,0xabe3,0x8477,0xc5fc,0xef5f,0xf79e,0xef5f,0xffff,0xffff,0xe578,0xc24a,0x7040,0x4100,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x2143,0x64a7,0x4365,0x2204,0x21c4,0x21c4,0x21c3,0x21c3,0x2a03,0x2a44,0x3284,0x3b25,0x4365,0x4be6,0x4c26,0x43e5,0x3ba5,0x3b64,0x43a5,0x5426,0x64a7,0x6d28,0x6529,0x95b1,0xffff,0xffff,0x9c22,0xd679,0xd6ff,0x9d37,0x8c77,0xc63c,0xdebf,0xbdbb,0x8477,0xad76,0xffff,0xffff,0xe75f,0xce3d,0xce3d,0xffff,0x636e,0x0000,0x0000,0x0000,0x0000,0x0000,0x1885,0x28c8,0x0006,0x3105,0xbbe4,0xdd20,0xe5e0,0xf662,0xffc3,0xe5a5,0xd903,0xf004,0xe9c5,0x93e5,0xcee6,0xffe5,0xf665,0xede3,0xec64,0xda83,0xc287,0xfdef,0xffea,0xffc9,0xffca,0xff47,0xede3,0xfde2,0xdce0,0xabe4,0x8c78,0xc5fc,0xdebd,0xe6ff,0xf79f,0xddb9,0x9a49,0xaa06,0x8b28,0x1a43,0x0a03,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1903,0x3a85,0x29c3,0x5ca7,0x2183,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0841,0x10c1,0x1942,0x2a44,0x32c4,0x3b65,0x4be6,0x3ba5,0x32c4,0x32c4,0x4325,0x4ba5,0x3321,0x6c29,0xffff,0xd5f1,0xacac,0xc67f,0x8cb9,0x73f5,0x8c76,0xc63d,0x8477,0xad38,0xffff,0xffff,0xffff,0xf7df,0xe6ff,0xef9f,0xc63c,0x2946,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0840,0x2091,0x3117,0x72cb,0xdba4,0xec63,0xdc62,0xc802,0xf005,0xe804,0xe804,0xd9c3,0x8be4,0xf1c6,0xf8c6,0xe9c6,0xf809,0xe808,0xf84c,0xfbab,0xffe9,0xffc9,0xff47,0xf623,0xfe22,0xeda3,0xcc60,0x9c28,0x7c38,0xb53a,0xad7b,0xbe3a,0x952d,0x4a80,0x42c0,0x756a,0x7e2c,0x7529,0x7d29,
0x0000,0x0000,0x0000,0x0000,0x0000,0x3a45,0x2143,0x0000,0x0000,0x4b65,0x5426,0x0040,0x0881,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0881,0x1983,0x2a44,0x3ac5,0x2a84,0x19c3,0x2a04,0x3244,0x2200,0x4327,0xc639,0xc5b2,0xdebe,0xad3a,0x8cb7,0x7bf5,0x94f8,0x8436,0xe6fd,0xffff,0xffdf,0xffdf,0xffff,0xe7df,0x5bb0,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x008b,0x6218,0x994e,0xc0cd,0xf98a,0xb003,0xa803,0xe804,0xf044,0xc003,0xf805,0xc884,0x8002,0xe005,0xc004,0xf808,0xe807,0xd808,0xfa8d,0xff4a,0xff87,0xfee4,0xfe62,0xfe22,0xfda1,0xd460,0xcc60,0x7b6d,0x6375,0x73f1,0x6cab,0x5c64,0x5c26,0x74ee,0xbe7a,0x6c2c,0x0000,0x2a01,0x3ac3,0x0000,0x0000,0x0000,0x0000,0x5be7,0x3a44,0x0000,0x0000,0x0000,0x0841,0x53e6,0x2202,0x1101,0x1101,0x0881,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x10c1,0x4ac5,0x5ba6,0x0900,0x1942,0x21c4,0x1140,0x3a87,0xc636,0xef9e,0xbdfd,0x94f9,0x8c77,0x8477,0x9d39,0xf79f,0xffdf,0xffdf,0xffff,0xb5fa,0x41c7,0x4001,0x4882,0x2841,0x5083,0x0000,0x0000,0x0000,0x0000,0x0000,0x48c3,0x7907,0xb949,0xf9c6,0xf904,0xe947,0x9802,0xb803,0xf845,0xc003,0xd004,0xf845,0x7002,0x7002,0xa803,0xb004,0xe846,0xb805,0xd888,0xfeea,0xffe6,0xe624,0xce26,0xbde6,0xada6,0x94a4,0xbce2,0x93a8,0x4a10,0x5bab,0x64a5,0x5c26,0x63ad,0x8c76,0xb57c,0xd63f,0x7c31,0x4288,0x4b27,0x08c0,
0x0000,0x0000,0x0000,0x4ba7,0x5be7,0x0000,0x0000,0x0000,0x0000,0x0000,0x2183,0x4ba5,0x1141,0x1141,0x1941,0x1941,0x0881,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x20c1,0x94ac,0x7cb1,0x1982,0x08c0,0x2143,0x08c0,0x4286,0xef5e,0xdeff,0xad7a,0x94b8,0x94f8,0xb5ba,0xdebe,0xe7df,0xe7ff,0x5cb2,0x0000,0xc884,0xfb6e,0xfa4b,0xf906,0xf989,0x8003,0x6842,0x0000,0x4842,0xd146,0xf987,0xf987,0xd843,0xf946,0xf906,0xe906,0x9002,0xc003,0xe044,0xa803,0xf005,0xb804,0x2800,0xb8c5,0x9905,0x8002,0xb805,0xb004,0xfac7,0xf785,0x9566,0x64e8,0x44a8,0x34a8,0x3467,0x34a8,0x44a7,0x4429,0x53e8,0x5be6,0x5329,0x5ace,0x7bb5,0x8c77,0x8c76,0x8476,0x9cf9,0x9d3a,0x8c78,0x7c35,0x0000,0x0000,0x1943,0x6ce8,0x1902,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x3ac4,0x3ac3,0x2a02,0x21c2,0x0941,0x19c2,0x21c2,0x1101,0x0801,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x94b7,0xc63d,0x4a89,0x08c0,0x10c1,0x0080,0x5b6b,0xe6ff,0xce7e,0xc63c,0xbdba,0xb5bb,0xbebf,0xe5bb,0xba4c,0x2000,0x9801,0xfa0a,0xfb6d,0xfa4b,0xf8c6,0xf1c9,0xd804,0xf805,0x9043,0x5801,0xf146,0xe105,0xe906,0xc884,0xe0c5,0xf0c5,0xe8c5,0x9002,0xc004,0xc803,0xa803,0xe804,0x5082,0x3001,0xc906,0x58c3,0x6802,0x9804,0xc804,0xc244,0x4c25,0x33e7,0x3c66,0x43a4,0x5322,0x5b22,0x5b22,0x5323,0x43e4,0x3ca4,0x3b66,0x49cd,0x6b30,0x8c75,0x8cb7,0x8c76,0xb5ba,0xbdbc,0xad3a,0x94b8,0x94b9,
0x0000,0x0000,0x3244,0x4b26,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1902,0x4ba5,0x3243,0x32c3,0x2a83,0x1981,0x1141,0x2202,0x2a02,0x1942,0x0841,0x0000,0x0000,0x0000,0x0000,0x1082,0x4208,0x0841,0x0000,0x8c35,0xbdbd,0x6bb0,0x1943,0x08c0,0x08c0,0x6bf0,0xd67f,0xd67d,0xc67d,0x9e3c,0xbdba,0xf9c9,0xf000,0xf804,0xf806,0xf147,0xfbad,0xfa8b,0xf8c6,0xfa0a,0xb844,0xd803,0xf844,0x8802,0xa8c4,0xd905,0xd884,0xc084,0xc084,0xe885,0xe8c5,0x9843,0xb804,0xb003,0xb003,0xb084,0x1943,0x6082,0x6843,0x3000,0x7002,0x9003,0xc004,0x4903,0x0a84,0x43e5,0x52c3,0x59c0,0x6a00,0x8280,0x9320,0xb360,0x9b60,0x5284,0x2ba7,0x4be9,0x8c76,0x9d39,0x9d39,0xbdfc,0xce7e,0xce7e,0xce7e,0xc5fc,0x9cf9,0x0000,0x0000,0x31c4,0x2984,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x3ac4,0x4c66,0x3a44,0x42c3,0x3b23,0x3a83,0x21c2,0x1181,0x2202,0x2a02,0x2182,0x10c1,0x0000,0x0000,0x8433,0xffff,0xc63c,0x7c32,0x6370,0x8cb8,0x94fa,0x7bf3,0x3206,0x08c0,0x1941,0x8476,0xb5fe,0xb67f,0xb4b6,0xfa09,0xfa49,0xf908,0xe003,0xf004,0xf8c6,0xfbad,0xfa8b,0xf8c5,0xfa0a,0xb884,0xc803,0xe804,0xb003,0x8843,0xd0c4,0xc044,0xc844,0xa843,0xd084,0xe885,0xa843,0xa803,0x9803,0xa803,0x6842,0x0081,0x5882,0x6043,0x7043,0x6001,0x8803,0x9803,0x3103,0x2b64,0x5ac2,0x4900,0x59c1,0x6a81,0x8321,0x9ba1,0xbc62,0xc421,0xc3a0,0x72c7,0x4bec,0x74b0,0xad38,0xad7a,0x7c37,0x8cb8,0xbdbb,0xdeff,0xffff,0xf7df,
0x0000,0x0000,0x0841,0x0841,0x0000,0x0000,0x0000,0x0000,0x0000,0x3802,0x0000,0x0000,0x1182,0x5b64,0xc106,0xb9c7,0x19c2,0x2ac3,0x53a5,0x4b64,0x2a02,0x1141,0x19c2,0x2242,0x1940,0x08c0,0x9d78,0xdeff,0xdeff,0xc63e,0x9d3b,0x6bb5,0x6372,0x73f5,0x73b5,0x3a08,0x00c0,0x0a46,0x93f5,0xf32e,0xf148,0xf9c8,0xfb6d,0xf9c9,0xe004,0xe804,0xf886,0xfacb,0xfa8b,0xf8c5,0xfa09,0xc0c5,0xc002,0xd803,0xc003,0x7802,0xb884,0xb043,0xc043,0x9803,0xb043,0xd884,0xb043,0x8803,0x8802,0x9002,0x2800,0x0000,0x6843,0x8084,0x6842,0x6002,0x7802,0x8802,0x41c4,0x1982,0x4980,0x6241,0x6241,0x7241,0x8b21,0xabe2,0xbc63,0xcca3,0xdce1,0xc3a0,0x7a47,0x6bb2,0xbe3b,0xef5f,0xc5fa,0x6bb3,0x8436,0xb5bb,0xb5b8,0x73ef,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x5082,0xa844,0x6002,0x0000,0x0081,0x6842,0xd885,0xfa8a,0x7326,0x0a82,0x19c1,0x4324,0x6426,0x53a4,0x2202,0x0941,0x11c0,0x1181,0x5acf,0xc63d,0xdf5d,0xce3d,0xb5bc,0x94f9,0x8438,0x6bb6,0x6332,0x5b32,0x1a08,0x51c4,0xe28b,0xf988,0xf988,0xfa0a,0xfacc,0xfb2c,0xe886,0xd803,0xf845,0xfa4a,0xfa8a,0xf8c6,0xf9c9,0xc0c5,0xb802,0xc843,0xc003,0x7002,0x8842,0x9043,0xb843,0x9003,0x8803,0xc043,0xb043,0x7802,0x7802,0x6802,0x1801,0x5082,0x8043,0x7884,0x6042,0x5001,0x7802,0x9843,0x4103,0x0000,0x0800,0x51c1,0x82c0,0x7ac0,0x82c1,0x9321,0xb3e1,0xcca2,0xd4e3,0xcca2,0xb360,0x82c6,0xad7a,0xe75f,0xffff,0xdefc,0x2104,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x3801,0xc8c4,0xc0c4,0xb043,0x6803,0x0000,0x5001,0xc8c5,0xea09,0x9c69,0x5da7,0x4c24,0x2281,0x1a02,0x4364,0x6465,0x4ba3,0x21c3,0x308e,0x3850,0x61d7,0xc5fd,0xefdf,0xce3e,0xbdbb,0x94fa,0x6bb5,0x3a4e,0x31cd,0xc28d,0xfbad,0xfb2c,0xf907,0xf0c6,0xfa8b,0xfa4b,0xfb2d,0xf989,0xd003,0xe804,0xfa09,0xfa8b,0xf886,0xf988,0xc0c5,0xa802,0xc003,0xc003,0x7002,0x6842,0x7842,0x9842,0x9003,0x7002,0x9042,0x9803,0x6802,0x5801,0x2000,0x88c4,0xb0c4,0x7042,0x8084,0x5802,0x5001,0x8803,0x9844,0x2001,0x0000,0x0000,0x0001,0x4a43,0x8362,0x9361,0x9b60,0xab60,0xb3e0,0xc461,0xd4a1,0xe4e0,0xc3e0,0x94b5,0xd6bf,0xe6fe,0xffff,0xc639,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x6003,0xb844,0xb8c4,0xa8c4,0xa844,0x4802,0x3001,0xb844,0xe988,0x9ca6,0x5cea,0x51d0,0x53e8,0x3be2,0x11c1,0x2202,0x5424,0x6c67,0x5113,0x5096,0x5059,0x699c,0xadb7,0xdf5d,0xce7e,0x8cf6,0x7433,0x4bb2,0x9a8d,0xfa08,0xfa4a,0xfacb,0xf989,0xe004,0xf147,0xfa8b,0xfa4b,0xfa8b,0xd804,0xd802,0xf948,0xfa4a,0xf085,0xf947,0xc8c5,0x9002,0xb803,0xb002,0x7002,0x4801,0x6002,0x7802,0x8002,0x5802,0x7002,0x8002,0x5001,0x2000,0x7001,0xf106,0x7883,0x9084,0x7843,0x4802,0x6802,0x9804,0xa804,0x1801,0x0000,0x0000,0x0902,0x3b26,0x1903,0x3901,0x6a41,0x8281,0x9321,0x9b21,0x92c1,0x61c0,0x41c3,0x8cb6,0xce3d,0xef9f,0xe75f,0xffff,0x636f,0x0000,0x0000,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x5803,0x9804,0x9043,0x9043,0x8043,0x7803,0x3802,0x7002,0xf186,0xaba8,0x3990,0x3813,0x494f,0x5ca6,0x4422,0x1a41,0x0980,0x3be0,0x5acc,0x4896,0x615a,0x609d,0x308f,0x32c3,0x5b6c,0x7338,0x7b38,0x3250,0x9a4a,0xfa09,0xf845,0xf988,0xf989,0xf886,0xd803,0xfa09,0xfa09,0xfa8b,0xe0c5,0xc802,0xf8c6,0xf9c8,0xe884,0xf906,0xc8c5,0x7801,0xb002,0x9802,0x7002,0x3801,0x4801,0x6001,0x6842,0x4801,0x5001,0x5001,0x2000,0x7801,0xf948,0xb905,0x6802,0xa885,0x6842,0x4801,0x7003,0xb805,0xa844,0x0800,0x0000,0x0800,0x4244,0x3a45,0x0000,0x0000,0x0001,0x0801,0x0800,0x0800,0x10c2,0x0102,0x00c0,0x5b6c,0xd67e,0xdebd,0xd6be,0xc5fe,0x8cf6,0x1101,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x2801,0x7004,0x7804,0x7003,0x4802,0x4001,0x4802,0x2801,0x9840,0xca0b,0x4115,0x4912,0x4853,0x498e,0x5466,0x3be2,0x2a44,0x2948,0x2a84,0x414e,0x50d7,0x611b,0x50d8,0x0883,0x288b,0x689d,0x48d8,0x3097,0x6888,0xf945,0xf845,0xf004,0xf8c6,0xf8c6,0xe004,0xe0c5,0xf9c9,0xf9c9,0xf148,0xb802,0xe085,0xf946,0xd844,0xf885,0xe084,0x6001,0x8043,0x7042,0x58c4,0x2082,0x3041,0x38c4,0x4001,0x4000,0x2000,0x2000,0x9083,0xfa8b,0xfa09,0x4841,0x9043,0x9084,0x5842,0x4801,0x9804,0xc806,0x7803,0x2800,0x3001,0x4001,0x5041,0x5001,0x5002,0x2001,0x0000,0x0000,0x0081,0x1183,0x1142,0x1101,0x0000,0x0000,0x94f7,0xd6bf,0xad7a,0xb5bc,0x9d37,0x1981,0x08c0,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1801,0x3802,0x4802,0x7084,0x9986,0xb9c7,0x99c6,0x78c2,0x9883,0x6956,0x515a,0x5917,0x3890,0x5955,0x7a19,0x62d1,0x6a92,0x5996,0x410f,0x308c,0x48d5,0x40d3,0x388f,0x611d,0x591f,0x691d,0x60ce,0x5800,0x9001,0xe085,0xe004,0xe804,0xe885,0xe845,0xd003,0xe906,0xf987,0xf988,0xb803,0xb003,0xf0c5,0xd044,0xc043,0xc884,0x6801,0x40c4,0x40c4,0x38c3,0x2841,0x2144,0x20c3,0x3082,0x1082,0x2000,0xd8c5,0xfa0a,0xea8b,0x5082,0x5001,0xa884,0x7843,0x4801,0x7003,0xc846,0x9804,0x4001,0x3801,0x4001,0x4001,0x4000,0x5001,0x7802,0x7842,0x3801,0x1182,0x2b25,0x1942,0x0000,0x0000,0x0000,0x0000,0x2104,0xd6bf,0xb5bb,0xe6ff,0x7bf2,0x0000,0x2203,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1081,0xb1c7,0xfacb,0xfa89,0xf205,0xea06,0xda08,0xa943,0x90c9,0x695a,0x615a,0x4913,0x691c,0x895f,0x819f,0x62cf,0x524f,0x48d6,0x308d,0x2089,0x308f,0x308f,0x389c,0x9957,0xf24c,0xe104,0x9801,0x6001,0x7802,0xb843,0xc803,0xe004,0xd844,0xc803,0xd044,0xf906,0xf907,0xd085,0x8801,0xd043,0xc843,0x9843,0xa8c4,0x3842,0x20c4,0x31c6,0x3103,0x20c4,0x2145,0x1082,0x0103,0x0082,0x7001,0xb884,0x7883,0x4801,0x3800,0x8043,0x9044,0x5802,0x4802,0xb845,0xb005,0x5001,0x3000,0x4001,0x4801,0x5801,0x6802,0x8042,0x9043,0xb884,0xe0c5,0xd247,0x18c1,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x524c,0xef5f,0xb57b,0x1043,0x0000,0x21c3,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x6905,0xea09,0xf208,0xd904,0xa883,0x70cb,0x7115,0x6915,0x590f,0x58ca,0x690e,0x5115,0x4913,0x795e,0x819f,0x795f,0x791f,0x5997,0x51d3,0x5919,0x308e,0x288b,0x1050,0x78cf,0xfb2b,0xfb6a,0xfa09,0xf908,0xd844,0x7802,0x7001,0x9002,0xb003,0xd004,0xc844,0xb003,0xc884,0xf0c5,0xe885,0x8802,0x7083,0x7883,0x6083,0x6085,0x4946,0x6365,0x8ca8,0x5ac7,0x2104,0x1103,0x00c2,0x5001,0xd844,0xe946,0x3001,0x3800,0x6002,0x7042,0x7843,0x6802,0x4001,0x8843,0xb044,0x5001,0x3000,0x4801,0x5801,0x6001,0x6002,0x7002,0x8042,0x9843,0xc084,0xe905,0xf948,0xc147,0x2082,0x0000,0x0000,0x0000,0x0000,0x0841,0x0040,0x52ca,0x2945,0x0000,0x1081,0x10c3,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x3082,0x5042,0x3000,0x4000,0x60d2,0x599f,0x515a,0x4918,0x595b,0x595c,0x5156,0x40cf,0x38cd,0x4912,0x715e,0x715f,0x715f,0x711f,0x591a,0x4916,0x48d8,0x2891,0x200e,0xe24b,0xfc6d,0xfacc,0xfa09,0xf9c9,0xf908,0xe844,0x8802,0x7002,0x8002,0x9002,0xb803,0xa803,0x9802,0xc043,0xf044,0xb043,0x28c3,0x48c4,0x3884,0x49c5,0x6ba4,0xce67,0x94e9,0x3246,0x3ba8,0x0144,0x6802,0xf948,0xfa0a,0x68c3,0x3801,0x9043,0x8002,0x7042,0x6842,0x4801,0x5842,0x9843,0x4801,0x2000,0x4001,0x5001,0x5001,0x5001,0x5801,0x7002,0x8002,0x9843,0xb043,0xd084,0xe0c5,0xf9c9,0xf1c9,0x10c2,0x1983,0x3a44,0x4b66,0x5c27,0x6467,0x5424,0x64a6,0x7529,0x6ce8,0x6468,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0001,0x0043,0x4113,0x5115,0x4110,0x5916,0x799e,0x719d,0x695b,0x6159,0x40d0,0x2889,0x388e,0x48d6,0x5118,0x5119,0x50da,0x3893,0x3091,0x2058,0x6092,0xfa89,0xfacb,0xfb2b,0xf9c9,0xf947,0xf948,0xf907,0xe844,0x8802,0x7002,0x7802,0x8002,0x9803,0x7802,0x8842,0xc802,0xb842,0x2905,0x2883,0x8366,0x9d25,0x7424,0x8469,0x52c8,0x2287,0x1a87,0x9145,0xf906,0xf988,0x5083,0x0000,0x5002,0x9043,0x6802,0x6002,0x5002,0x4001,0x7841,0x4801,0x1800,0x3801,0x3801,0x3800,0x4801,0x6802,0x7802,0x8802,0x9803,0xb043,0xd044,0xb843,0x6002,0x6801,0xc003,0x79c5,0x3366,0x4b66,0x4ba6,0x53e6,0x5c26,0x64a7,0x6d28,0x7da9,0x8e2a,0x96ab,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x38cf,0x6158,0x4912,0x1887,0x2087,0x410f,0x4911,0x5115,0x5957,0x5956,0x4912,0x30cb,0x308b,0x288a,0x204a,0x2049,0x2049,0x308e,0x3090,0x204b,0x000c,0x914e,0xfa89,0xf907,0xf9c8,0xfa09,0xf906,0xe885,0xf8c6,0xf887,0xe844,0x7802,0x6802,0x7002,0x6801,0x6802,0x5801,0x7842,0x78c4,0x4083,0x4a47,0x9529,0xce69,0x7428,0x29c7,0x0985,0x09c4,0xb987,0xfa0a,0xc906,0x4801,0x3801,0x3801,0x4802,0x7002,0x5802,0x4801,0x3001,0x5001,0x5001,0x1800,0x2800,0x3000,0x3801,0x4801,0x6001,0x7002,0x7802,0x8802,0x9003,0xc003,0x9843,0x3143,0x1184,0x1143,0x20c2,0x60c3,0x3184,0x21c4,0x2a04,0x2a44,0x3284,0x32c4,0x3b25,0x43a5,0x5426,0x64a7,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x38ce,0x5116,0x40d1,0x5916,0x6158,0x6158,0x4911,0x4912,0x5113,0x40cf,0x40cf,0x4912,0x5115,0x48d2,0x38d0,0x388f,0x308d,0x308c,0x2049,0x1849,0x0006,0xb1c9,0xfa49,0xf085,0xf004,0xf886,0xf907,0xf0c6,0xd004,0xd044,0xf845,0xe844,0x7001,0x4801,0x5802,0x4801,0x4001,0x3841,0x50c4,0x7041,0x6ac8,0x3ac8,0x4286,0x4b69,0x4bea,0x1b27,0x70c3,0xf906,0xfa09,0x2841,0x1000,0x6002,0x5002,0x3801,0x5001,0x4001,0x3001,0x3001,0x4001,0x2000,0x2000,0x2800,0x3801,0x4001,0x4801,0x5801,0x6802,0x7802,0x8802,0xc003,0xb003,0x1943,0x09c3,0x1983,0x1983,0x11c4,0x21c4,0x29c4,0x29c4,0x2a04,0x3244,0x3284,0x3284,0x32c4,0x32c4,0x3324,0x3b64,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0843,0x1845,0x30cd,0x6159,0x799e,0x799f,0x695b,0x5115,0x4912,0x38ce,0x308c,0x695a,0x5917,0x48d2,0x4913,0x4912,0x50d8,0x591a,0x40d2,0x308d,0x208b,0x0807,0xca09,0xfa09,0xf044,0xe804,0xe804,0xe804,0xe885,0xe844,0xd004,0xc803,0xe044,0xd043,0x7802,0x4001,0x4801,0x3882,0x18c2,0x2041,0x40c3,0x4245,0x2205,0x2a06,0x1a07,0x01c4,0x88c4,0xe803,0xc844,0x7042,0x1800,0x3801,0x4001,0x5001,0x3001,0x3001,0x3801,0x2801,0x3001,0x3000,0x2000,0x3000,0x4001,0x4801,0x5801,0x6802,0x7802,0x8802,0x9002,0xc003,0xc044,0x3903,0x0183,0x1902,0x10c2,0x10c2,0x10c2,0x1102,0x1902,0x1942,0x1943,0x2183,0x29c4,0x2a44,0x32c4,0x3b25,0x43a5,0x43a4,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x2089,0x719d,0x5917,0x695a,0x899f,0x819f,0x715c,0x5115,0x5113,0x30cd,0x2088,0x38ce,0x6158,0x5113,0x6118,0x611a,0x48d3,0x308e,0x48d5,0x50da,0x48d7,0x40d3,0x108a,0xc946,0xf8c6,0xe004,0xd804,0xd004,0xd004,0xd004,0xd804,0xe044,0xd804,0xc003,0xc803,0xc003,0x7802,0x5001,0x4001,0x2945,0x1104,0x0883,0x2143,0x3285,0x1a04,0x00c2,0x91c7,0xf989,0xb003,0x1000,0x1800,0x4001,0x4801,0x3801,0x3801,0x3001,0x2001,0x2801,0x2001,0x3000,0x3000,0x3000,0x3001,0x3001,0x3801,0x3801,0x4801,0x6802,0x9002,0xb003,0xa803,0x2041,0x0040,0x0841,0x0841,0x0841,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0841,0x1081,0x1902,0x2183,0x32c7,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1881,0x799b,0x91df,0x715d,0x799f,0x89df,0x715c,0x4913,0x4913,0x30cb,0x2889,0x2048,0x388e,0x719b,0x799f,0x799f,0x695d,0x5919,0x308d,0x1848,0x3892,0x50dc,0x40d6,0x108c,0x5045,0xb002,0xb803,0xb043,0xb003,0xb003,0xb803,0xb803,0xb803,0xc803,0xd003,0xc003,0xb002,0xa802,0x7001,0x4801,0x30c4,0x2104,0x1082,0x0882,0x0942,0x0183,0x68c3,0xfa0a,0xfa8b,0x5842,0x0800,0x3801,0x3801,0x4001,0x3801,0x3001,0x2801,0x1800,0x1000,0x1800,0x2000,0x1000,0x0000,0x0000,0x0000,0x0000,0x0000,0x08c1,0x1902,0x3041,0x4801,0x2001,0x0081,0x29c3,0x3ac5,0x4365,0x4365,0x3b25,0x3284,0x29c3,0x1902,0x0040,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x18ca,
0x0000,0x0000,0x0000,0x0000,0x0000,0x5983,0x8183,0x91df,0x615c,0x4912,0x819f,0x819f,0x5917,0x4913,0x30cc,0x38cc,0x388f,0x204a,0x5955,0x899f,0x819f,0x795f,0x695e,0x48d7,0x288c,0x1045,0x1045,0x288e,0x308f,0x188c,0x4046,0x8801,0x7002,0x7802,0x7802,0x7801,0x6801,0x6801,0x6801,0x7002,0x7002,0x7001,0x6801,0x6001,0x5000,0x30c3,0x1903,0x2041,0x08c2,0x10c3,0x1841,0x8083,0xf948,0xd907,0x78c4,0x2000,0x3001,0x3801,0x3801,0x3801,0x3001,0x2001,0x1800,0x1000,0x1800,0x2000,0x2000,0x2001,0x3001,0x3001,0x1000,0x0040,0x0101,0x1942,0x08c1,0x0000,0x0000,0x0101,0x3b24,0x5426,0x5426,0x53e6,0x53e7,0x43a5,0x3b24,0x4325,0x42c7,0x3ac5,0x2203,0x0841,0x0000,0x0000,0x0000,0x0000,0x0000,0x0842,0x0000,0x0000,0x0000,0x0000,0x7a45,0xba44,0x8983,0x7956,0x5115,0x30cd,0x6959,0x5915,0x5115,0x40d0,0x30cc,0x48d5,0x4052,0xb53a,0x7ad7,0x3812,0x799f,0x799f,0x691d,0x48d3,0x1046,0x1046,0x204a,0x1848,0x204a,0x0002,0x7000,0xd003,0x9802,0x9002,0x9002,0x9002,0x8802,0x8802,0x8002,0x7801,0x6801,0x5001,0x4801,0x3801,0x3000,0x2882,0x1882,0x0881,0x6042,0x7043,0x8842,0xc803,0x8884,0x2800,0x1000,0x3001,0x3001,0x3801,0x3001,0x2801,0x1800,0x1000,0x1800,0x2800,0x3800,0x4001,0x4801,0x4801,0x5001,0x6801,0x7802,0x5842,0x2101,0x0080,0x0000,0x0000,0x1102,0x3284,0x4365,0x4ba6,0x4ba6,0x4366,0x4366,0x4ba7,0x4ba7,0x3b63,0x3244,0x3a48,0x4b68,0x3b25,0x0841,0x0000,0x0000,0x0000,0x0000,0x0000,
0x0000,0x0000,0x0000,0x7a46,0xdac6,0x9983,0x8142,0x2840,0x2089,0x40d0,0x40cf,0x40cf,0x5115,0x4911,0x50d5,0x4856,0x8bf8,0xbe7a,0x7bb6,0x38cf,0x4091,0x6119,0x4913,0x1085,0x0000,0x204a,0x3090,0x3051,0x184f,0x1841,0xd084,0xf907,0xf1c9,0xfa4a,0xfa4b,0xfa4a,0xfa09,0xf988,0xf947,0xf906,0xf0c5,0xe884,0xd044,0xb803,0x9802,0x7801,0x7001,0xc844,0xe045,0x4801,0x6001,0x5001,0x2000,0x3001,0x4001,0x3801,0x3801,0x3001,0x2000,0x1000,0x1000,0x2000,0x3000,0x3800,0x3801,0x3801,0x4801,0x5002,0x4801,0x5001,0x7002,0x9803,0x9043,0x4842,0x0000,0x00c0,0x2a03,0x3b25,0x53e7,0x5428,0x5427,0x4365,0x4365,0x4be5,0x4289,0x420c,0x3ac6,0x398b,0x2087,0x3284,0x29c4,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x61c5,0xfba8,0xba04,0xa9c3,0x5881,0x0000,0x0002,0x6959,0x4911,0x4912,0x6158,0x4913,0x4892,0x9439,0x9537,0x6bb3,0xbdfc,0x7bf6,0x398d,0x314b,0x2148,0x0040,0x1005,0x48d8,0x3895,0x4098,0x0009,0xb144,0xfa8c,0xfacc,0xfb2d,0xfa8b,0xfa0a,0xfa09,0xf988,0xf948,0xf907,0xf8c6,0xf085,0xe844,0xd843,0xb803,0x9002,0x9043,0xb043,0xb044,0x4801,0x3801,0x4802,0x3801,0x4001,0x3801,0x3801,0x3001,0x2800,0x1800,0x1800,0x2000,0x2800,0x3800,0x4000,0x4801,0x5001,0x6001,0x6001,0x6001,0x6001,0x5801,0x5801,0x7002,0x9843,0xc085,0x80c4,0x1901,0x19c2,0x32c4,0x4ba6,0x5c68,0x5c2a,0x5428,0x43e4,0x4be6,0x5427,0x394d,0x3851,0x20c8,0x0000,0x0000,0x0881,0x0000,0x0000,0x1845,0x390e,0x1045,
0x0000,0x1041,0xfc2a,0xca04,0xb204,0xa942,0x2800,0x0001,0x6158,0x719c,0x1044,0x38ce,0x4911,0x1809,0x6b2f,0xcefe,0x73f5,0x9d39,0xbdfb,0x7c35,0x532f,0x320b,0x3a0d,0x10c2,0x2009,0x50d8,0x40d5,0x104b,0x0840,0xf988,0xf949,0xf8c6,0xf886,0xf886,0xb043,0x6002,0x8802,0xf085,0xf885,0xe044,0xd043,0xb843,0xa843,0x9003,0x4842,0x3001,0x2801,0x2001,0x3801,0x4801,0x3801,0x3001,0x2801,0x2801,0x2801,0x2000,0x1800,0x1800,0x2800,0x3000,0x3001,0x3801,0x4801,0x5001,0x5001,0x6001,0x8842,0x9083,0x7002,0x7002,0x7002,0x6002,0x7002,0x9003,0xd085,0x7103,0x09c2,0x2a04,0x2a04,0x4c24,0x4aca,0x390f,0x4ba8,0x4c64,0x6567,0x5c29,0x284c,0x0803,0x1845,0x0000,0x0000,0x0000,0x2088,0x4912,0x5956,0x4911,0x0000,0x69c5,0xfb68,0x9943,0xca85,0x98c0,0x1000,0x0846,0x6198,0x2088,0x0000,0x0842,0x0801,0x0000,0x5acd,0x6bb2,0x7bf2,0xdebd,0xce3d,0x73f3,0x6b73,0x6333,0x6372,0x18c2,0x0002,0x38d0,0x2049,0x0000,0x0000,0xe845,0xf886,0xf8c6,0xf948,0xb105,0x78c3,0x7042,0x6001,0x8082,0xd105,0xf906,0xe885,0xc844,0xb043,0x9003,0x8002,0x6802,0x6002,0x5802,0x4801,0x3801,0x3001,0x3001,0x3001,0x2800,0x1800,0x2000,0x2800,0x2800,0x3000,0x3801,0x3801,0x4001,0x5801,0x6002,0x6802,0x5801,0x6001,0x9883,0xb905,0x8843,0x8802,0x8803,0x7002,0x7802,0x9803,0x8083,0x19c2,0x2203,0x0802,0x29c4,0x42c9,0x200e,0x204a,0x3206,0x2946,0x3a08,0x410f,0x5116,0x4110,0x28ca,0x30cc,0x2889,0x5115,0x5115,0x5113,0x5956,
0x0000,0xcb28,0xd982,0x9103,0xe2c6,0x9080,0x0800,0x0002,0x0842,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x6bed,0xffdf,0xde7e,0x7c73,0x8c78,0xbdbc,0xd67f,0x6bb0,0x0880,0x08c0,0x18c3,0x1844,0x1005,0x4887,0xfa4a,0xfb2d,0xfb6e,0xb986,0x5841,0x7842,0x8042,0x6842,0x4800,0x4001,0x6842,0x9043,0x9843,0xa843,0xa803,0x9802,0x8802,0x8002,0x6001,0x5801,0x5801,0x5001,0x4801,0x3801,0x2000,0x2000,0x3800,0x4801,0x4001,0x3801,0x4801,0x5801,0x4801,0x5001,0x6802,0x8043,0x8843,0x7002,0x6001,0xa843,0xd105,0x98c4,0xa803,0xb844,0x9043,0x9802,0x6042,0x0982,0x2243,0x1903,0x1009,0x208c,0x204a,0x1808,0x1008,0x1809,0x304f,0x38ce,0x2088,0x38ce,0x715c,0x799e,0x4912,0x5113,0x6159,0x719d,0x38cd,0x2103,0xe2c7,0x6800,0x9984,0xe2c6,0x7840,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x10c1,0x2ac2,0xc6b9,0xe6fd,0x63ed,0x9d39,0xef5f,0xf79f,0xad76,0x2182,0x10c1,0x2142,0x1900,0x08c1,0x0041,0xda0a,0xfb6e,0xf24a,0x9905,0x6801,0x7001,0x6802,0x5801,0x4801,0x4801,0x4001,0x2800,0x2000,0x3800,0x7042,0x7842,0x6802,0x5802,0x5001,0x5001,0x5001,0x4801,0x3801,0x4000,0x2000,0x2801,0x4000,0x4800,0x5801,0x5801,0x4801,0x4001,0x6002,0x7002,0x5001,0x6001,0x7842,0x9884,0xa884,0x8043,0x6801,0xb043,0xe146,0xa8c4,0xc043,0xd105,0xc0c4,0x8883,0x1102,0x0981,0x2185,0x200d,0x180d,0x180c,0x180a,0x180a,0x304f,0x308e,0x2089,0x40d0,0x6118,0x6118,0x5918,0x48d2,0x5917,0x695a,0x38ce,0x0000,
0x30c2,0x40c3,0x4840,0xb142,0xdac7,0x9102,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x10c2,0x5426,0x5c67,0x5c28,0x3b23,0x53aa,0x94f8,0x84b1,0x5369,0x1100,0x1940,0x2182,0x1942,0x1901,0x0080,0x3102,0xfa49,0xd946,0x6000,0x5000,0x7002,0x6801,0x5001,0x4041,0x4041,0x3041,0x2801,0x1801,0x3001,0x3801,0x2000,0x2800,0x3801,0x3801,0x5001,0x4801,0x3800,0x3001,0x5801,0x5801,0x2000,0x4001,0x7001,0x6001,0x7001,0x7001,0x8002,0x6802,0x5001,0x8042,0x7802,0x5801,0x7002,0x9043,0xb8c5,0xb8c4,0x9843,0x7801,0xb843,0xe186,0xb8c4,0xd884,0xe146,0xe947,0x70c3,0x0100,0x1903,0x20c8,0x20c8,0x20c8,0x2088,0x204a,0x200c,0x200c,0x3852,0x40d2,0x40d1,0x5115,0x5116,0x40d1,0x5115,0x38ce,0x1043,0x2889,0x0000,0x0000,0x7102,0xa942,0x4903,0xb246,0x2841,0x0000,0x0000,0x0000,0x0000,0x0041,0x4ba6,0x64a7,0x53e6,0x3323,0x2ac2,0x2a83,0x1a41,0x11c0,0x0980,0x19c2,0x21c2,0x1941,0x10c1,0x0881,0x0080,0x50c3,0xe084,0x5000,0x4000,0x4041,0x2880,0x1880,0x10c1,0x0881,0x0081,0x0040,0x0000,0x3001,0x8803,0x6802,0x5801,0x6002,0x4001,0x5801,0x6001,0x4000,0x5801,0x6001,0x9042,0x5801,0x2801,0x5801,0xb042,0x7001,0x9842,0x9042,0xa803,0xa843,0x8042,0x6802,0xb044,0x8002,0x6801,0x8802,0xa884,0xc906,0xc106,0xb043,0x8001,0xb844,0xf987,0xd904,0xe105,0xe9c8,0xf188,0x4903,0x1203,0x3ac4,0x4ba4,0x5425,0x5425,0x53e5,0x4324,0x31c7,0x288c,0x280f,0x388f,0x40d1,0x308b,0x2088,0x30cc,0x4912,0x695a,0x6159,
0x0000,0x0000,0x9183,0x7942,0x0000,0x1881,0x2841,0x0000,0x0000,0x0000,0x0000,0x3244,0x5ca8,0x43a5,0x3323,0x3323,0x3b64,0x3324,0x3323,0x32c4,0x2a83,0x2a43,0x2202,0x1982,0x1101,0x0900,0x00c0,0x1840,0x3800,0x1080,0x10c1,0x00c2,0x08c4,0x1887,0x2047,0x0000,0x0000,0x0000,0x2841,0xa803,0x8802,0x6001,0x8043,0x6001,0x6002,0x8842,0x5801,0x6841,0x8042,0x8802,0xb843,0x5801,0x3000,0x6001,0xd084,0x8002,0xb043,0xc884,0xb843,0xc084,0xc0c4,0x7802,0x9083,0xc084,0x6802,0x8002,0x9803,0xc0c4,0xd187,0xc946,0xb884,0x9002,0xc043,0xf946,0xf145,0xe145,0xf948,0x8944,0x0202,0x2243,0x32c4,0x4ba5,0x5c67,0x6d28,0x7568,0x6525,0x4be4,0x31c6,0x200b,0x1809,0x2047,0x38cd,0x4912,0x6118,0x719d,0x799f,0x0000,0x0800,0x58c2,0x1041,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0881,0x4be6,0x43a5,0x3363,0x3ba5,0x3ba5,0x3ba4,0x3be4,0x3ba5,0x3ba5,0x3363,0x2322,0x22c1,0x2242,0x19c2,0x1942,0x2103,0x2946,0x2107,0x28c8,0x2086,0x3049,0x384a,0x384b,0x1806,0x0000,0x0000,0x1801,0xa803,0xb003,0x6801,0xa843,0x8843,0x7001,0xb083,0x8843,0x6001,0xa843,0xa843,0xb843,0xd084,0x7002,0x4001,0x6841,0xe8c4,0xa843,0x9802,0xf0c5,0xe0c5,0xd884,0xe106,0xb884,0x7802,0xd0c5,0xb043,0x6802,0x9002,0xb843,0xd8c5,0xd187,0xc947,0xc8c4,0x9802,0xc003,0xe906,0xf946,0xe905,0x4a04,0x2ac3,0x3b23,0x2a83,0x19c2,0x2243,0x43a6,0x64e8,0x7daa,0x75a9,0x5ce5,0x3283,0x0804,0x1006,0x38ce,0x5116,0x6158,0x6159,0x6157,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x2a03,0x43a5,0x3324,0x3b65,0x3ba5,0x4465,0x4466,0x43e5,0x4ba5,0x4b64,0x4b26,0x5a8b,0x5a4b,0x518b,0x510c,0x384a,0x618e,0x8a13,0x7111,0x484c,0x2808,0x384b,0x3049,0x2808,0x0801,0x0000,0x0000,0x8042,0xd804,0x7802,0xb843,0xc084,0x7002,0xb884,0xd084,0x7802,0x9003,0xd0c4,0xc084,0xd044,0xe8c5,0x8802,0x5801,0x7002,0xf0c5,0xd884,0x9002,0xf106,0xf9c8,0xf0c5,0xe106,0xf988,0x9843,0x9844,0xf0c5,0x8802,0x7802,0xb803,0xd884,0xe905,0xc947,0xc106,0xe105,0xb843,0xb803,0xf086,0x5903,0x0201,0x2a42,0x3ac3,0x53a4,0x5c25,0x4364,0x1a02,0x3324,0x64e7,0x7da9,0x85ea,0x6526,0x3b24,0x1846,0x284a,0x410f,0x4911,0x5113,0x4911,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0041,0x3284,0x3323,0x3364,0x4425,0x3c25,0x3324,0x3a44,0x4a43,0x4a02,0x4200,0x69cb,0x9999,0x7912,0x6052,0x400d,0x48ca,0x8213,0x7151,0x508d,0x2808,0x3049,0x388a,0x3049,0x1805,0x0000,0x0000,0x3041,0xd804,0x9803,0x9002,0xf106,0x8842,0x9803,0xe8c5,0xc884,0x7801,0xb884,0xe106,0xd884,0xd884,0xf106,0x9843,0x7002,0x7002,0xf106,0xf906,0x9802,0xd044,0xfa4a,0xfa08,0xe907,0xfa4a,0xe947,0x8802,0xe0c5,0xe085,0x7801,0x9802,0xd843,0xf905,0xe105,0xb085,0xb885,0xf187,0xd0c5,0xb803,0x6a82,0x2ac2,0x2202,0x11c0,0x1181,0x3283,0x6465,0x5c66,0x1a02,0x2ac3,0x5ce7,0x7da9,0x85ea,0x64e5,0x3245,0x300e,0x388d,0x4911,0x4912,0x40cf,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0881,0x32c4,0x32c3,0x3ba4,0x2ac4,0x2983,0x3942,0x49c2,0x5202,0x4a02,0x3a00,0x6a0b,0xa99b,0x7095,0x4810,0x3104,0x824f,0x9a17,0x7111,0x484d,0x2807,0x384a,0x384b,0x2808,0x0002,0x0000,0x0000,0x9003,0xc803,0x8002,0xf0c5,0xd0c4,0x8802,0xe8c5,0xf906,0xb043,0x9002,0xd8c5,0xe946,0xe084,0xe084,0xf906,0xb844,0x8802,0x7802,0xe106,0xf9c8,0xc044,0xb002,0xfa4a,0xfb6d,0xf9c9,0xfa8c,0xfacc,0xc043,0xb044,0xf946,0xc044,0x7801,0xc043,0xf905,0xf9c7,0xe106,0x9804,0xb0c5,0xf949,0xe1c5,0xc421,0xb362,0x49c2,0x2185,0x2242,0x11c0,0x11c1,0x5424,0x6ce6,0x2ac3,0x2b23,0x5ca6,0x7da9,0x85ea,0x5ca5,0x3109,0x280c,0x38cd,0x48d2,0x4912,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1101,0x2a83,0x3364,0x2203,0x3142,0x6283,0x5ac3,0x4a43,0x4a03,0x4a02,0x4201,0x4a02,0x68d1,0x6016,0x38c5,0x5a45,0xba9a,0x91d7,0x68d2,0x408b,0x3905,0x404c,0x404c,0x1806,0x0000,0x0000,0x2801,0xc803,0xa803,0xd084,0xf906,0xb043,0xd0c4,0xf947,0xf947,0xa803,0xc003,0xe906,0xf147,0xf0c5,0xe0c5,0xf906,0xc884,0xa802,0x8002,0xc885,0xfa09,0xf147,0x9802,0xf147,0xfbef,0xfacb,0xfa8b,0xfbaf,0xf947,0xb003,0xf106,0xf947,0xa802,0x9002,0xd084,0xf987,0xfa49,0xe106,0xa803,0xc085,0x9104,0x1840,0x1000,0x0800,0x0805,0x30cb,0x3205,0x2281,0x11c1,0x4ba3,0x6ca6,0x2243,0x3b64,0x6d27,0x7da9,0x7da8,0x3b24,0x2009,0x288b,0x38ce,0x5115,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1101,0x2a83,0x2243,0x0000,0x2901,0x5a42,0x5a01,0x5201,0x49c1,0x41c1,0x49c2,0x4200,0x4183,0x4146,0x3200,0x724c,0xc29d,0x8195,0x5011,0x3888,0x4a03,0x408c,0x300b,0x3184,0x3a02,0x1902,0x7002,0xc002,0xd105,0xf988,0xe945,0xc083,0xf987,0xf9c8,0xe947,0xa802,0xe084,0xf947,0xf147,0xf906,0xe906,0xf947,0xe105,0xb843,0x9002,0xb803,0xf9c9,0xfa49,0xb844,0xc803,0xfbae,0xfbef,0xfa4b,0xfbaf,0xfa4b,0xd804,0xc044,0xfa09,0xf106,0x9802,0xb043,0xe0c4,0xfa08,0xfa8b,0xf948,0x6082,0x0080,0x0881,0x0000,0x0000,0x0000,0x1808,0x304f,0x31c6,0x2ac0,0x11c1,0x53e4,0x53e5,0x1a42,0x5466,0x7da8,0x7de9,0x5ca5,0x2908,0x2009,0x2889,0x38ce,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1101,0x2202,0x0841,0x0000,0x0000,0x0000,0x20c1,0x4141,0x5200,0x49c0,0x49c1,0x49c1,0x4a00,0x4a40,0x3a00,0x9292,0xd29f,0x70d6,0x380e,0x4185,0x52c1,0x2809,0x3048,0x5282,0x4a83,0x4a03,0x9802,0xc085,0xfacb,0xfa8a,0xe946,0xe905,0xfa49,0xfacc,0xd106,0xb803,0xf987,0xf1c8,0xf187,0xf9c8,0xe988,0xf9c9,0xf147,0xc884,0xb003,0xb002,0xf948,0xfacb,0xe987,0xb001,0xfa0a,0xfcb2,0xfa8b,0xfb6e,0xfb6e,0xf8c6,0xc803,0xe147,0xfa8a,0xe106,0xb042,0xb843,0xc843,0xf907,0xf989,0x7143,0x1a00,0x83a3,0xac64,0x7b64,0x20c2,0x0805,0x1809,0x1007,0x2182,0x2ac2,0x1a02,0x5c25,0x3b24,0x2b24,0x6d27,0x85e9,0x6d66,0x4248,0x300e,0x288a,0x288a,
0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x1101,0x1101,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x20c1,0x49c1,0x6241,0x5a00,0x5a01,0x5a41,0x4a40,0x9a90,0xba1d,0x504f,0x4105,0x5a81,0x5a81,0x2885,0x4184,0x5a81,0x3a41,0x5181,0x9000,0xd1c9,0xfc70,0xfacb,0xf105,0xf9c8,0xfb6d,0xfb2d,0xc044,0xd0c5,0xfa8b,0xea49,0xe987,0xfacb,0xf1c9,0xfa4a,0xf9c8,0xc884,0xc804,0xb003,0xf086,0xfa8b,0xfa8a,0xb043,0xd003,0xfbaf,0xfbef,0xfa4b,0xfb6d,0xf988,0xf004,0xc044,0xfa49,0xfb2c,0xd906,0xa803,0xa801,0xa8c1,0xba82,0x8241,0x61c1,0x5a41,0xaca3,0xffc6,0xe62a,0x204d,0x1009,0x1006,0x1007,0x2a03,0x2281,0x32c3,0x53a4,0x2a83,0x4c65,0x7da9,0x7de7,0x4b65,0x4091,0x48d3,0x38ce,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x10c1,0x0881,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0000,0x0001,0x2901,0x49c1,0x5a41,0x6241,0x6281,0x6a82,0x6a44,0x6281,0x6b20,0x6ac1,0x6ac2,0x62c1,0x6281,0x5201,0x39c0,0x3900,0x8001,0xf28b,0xfcb2,0xfa49,0xe8c4,0xfa49,0xfbef,0xfacc,0xb802,0xe1c9,0xfbef,0xea09,0xe105,0xfb6d,0xea09,0xf9c8,0xfa09,0xc843,0xd044,0xb803,0xf005,0xf989,0xfa4a,0xe106,0xa801,0xf989,0xfc31,0xfacc,0xfa0a,0xfa8b,0xf886,0xd003,0xc0c4,0xfa0b,0xf9cb,0x90c4,0x4900,0x6a40,0x8b60,0xb3a1,0xb361,0x7a41,0x5201,0x93e0,0xd526,0x3890,0x180c,0x204b,0x0806,0x1044,0x32c4,0x2241,0x4ba4,0x3283,0x3b64,0x75a8,0x7de9,0x5425,0x410f,0x58d7,0x4910,

};


